export interface ClientSize {
    clientHeight?: number;
    clientWidth?: number;
}
export interface DatasetLength {
    rowCount?: number;
    columnCount?: number;
}
export interface ScrollSize {
    scrollHeight?: number;
    scrollWidth?: number;
}
export interface ScrollPosition {
    scrollLeft?: number;
    scrollTop?: number;
}
export declare enum ScrollAxisName {
    VERTICAL = "vertical",
    HORIZONTAL = "horizontal"
}
export interface ScrollAxis<T> {
    [ScrollAxisName.VERTICAL]?: T;
    [ScrollAxisName.HORIZONTAL]?: T;
}
export declare enum ScrollDirection {
    UP = "up",
    DOWN = "down",
    LEFT = "left",
    RIGHT = "right"
}
export declare type ScrollDirectionState = Partial<Record<ScrollDirection, boolean>>;
export declare type ScrollParams = ScrollSize & ScrollPosition & ClientSize;
export declare type EventListenerFn = (type: 'scroll', callback: () => void) => void;
export declare type SetRefFn = (ref: any) => void;
export declare type ScrollingElementRef = Required<ScrollSize> & Required<ScrollPosition> & Required<ClientSize>;
export declare type RegisterEventListener = {
    addEventListener: EventListenerFn;
    removeEventListener: EventListenerFn;
};
export interface ScrollingContainerRef {
    scrollingElement: ScrollingElementRef | null;
    registerEventListener: RegisterEventListener | null;
}
export declare type InfiniteScrollState = DatasetLength & Required<ScrollSize> & Required<ClientSize> & {
    isLoading: boolean;
    thresholdReached: ScrollDirectionState;
    computedScrollThreshold: Required<ScrollAxis<number>>;
};
export declare type UseInfiniteScrollProps = DatasetLength & {
    hasMore: ScrollDirectionState;
    next: (direction: ScrollDirection) => Promise<void>;
    onScroll?: (value: Required<ScrollParams>) => void;
    scrollThreshold?: number | string;
    initialScroll?: {
        top?: number;
        left?: number;
    };
    reverse?: {
        column?: boolean;
        row?: boolean;
    };
    windowScroll?: boolean;
};
export interface UseInfiniteScrollResult {
    setRef: SetRefFn;
}
export declare type InfiniteScrollProps = UseInfiniteScrollProps;
export declare type ScrollOffsetValues = Required<ScrollDirectionState>;
export interface InfiniteScroll {
    props: InfiniteScrollProps;
    state: InfiniteScrollState;
    _scrollingContainerRef?: ScrollingContainerRef;
    setRef: SetRefFn;
    clearListeners: () => void;
    update: (props: InfiniteScrollProps) => void;
}
